package com.dominikdorn.lyrix.domain;

import javax.persistence.*;
import java.sql.Date;

/**
 * Dominik Dorn
 * 0626165
 * dominik.dorn@tuwien.ac.at
 */
@Table(name = "lytalbum", schema = "lyriks")
@Entity
public class Album {
    @Id
    @Column(name = "nalbumnr")
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "album_gen")
    @SequenceGenerator(name = "album_gen",
            sequenceName = "lytalbum_nalbumnr_seq",
    allocationSize = 1)
    private long id;

    @Column(name = "stitle")
    @Basic
    private String name;

    @Column(name = "nusernr")
    @Basic
    private int userId;

    @Column(name = "drelease")
    @Basic
    private Date releaseDate;

    /**
     * 1360 - default
     * 1310     lytalbum	online
     * 1320     lytalbum	deleted
     * 1330     lytalbum	hidden
     * 1340     lytalbum	lockeddubious
     * 1350 	lytalbum	lockedveto
     * 1360 	lytalbum	unapproved
     */
    @Column(name = "nstatusnr")
    @Basic
    private int statusId;

    @Column(name = "ndiscs")
    @Basic
    private int discCount;

    /**
     * 310  	lytalbum	album	Normales Album
     * 320  	lytalbum	bestoff	Best-Off Album
     * 330  	lytalbum	maxi	Maxi-CD
     * 340  	lytalbum	compilation	Compilation of Tracks
     * 350  	lytalbum	Single
     * 360  	lytalbum	undefined	Undefiniert
     */
    @Column(name = "ntypenr")
    @Basic
    private long typeId;

    public Album() {
    }

    public Album(String name, int userId) {
        this.name = name;
        this.userId = userId;
        this.statusId = 1360;
        this.typeId = 360;
    }

    public Album(int id, String name, int userId) {
        this(name, userId);
        this.id = id;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Album album = (Album) o;

        if (id != album.id) return false;
        if (discCount != album.discCount) return false;
        if (userId != album.userId) return false;
        if (releaseDate != null ? !releaseDate.equals(album.releaseDate) : album.releaseDate != null) return false;
        if (name != null ? !name.equals(album.name) : album.name != null) return false;
        if (typeId != album.typeId) return false;
        return true;
    }

    @Override
    public int hashCode() {
        long result = id;
        result = 31 * result + (name != null ? name.hashCode() : 0);
        result = 31 * result + userId;
        result = 31 * result + (releaseDate != null ? releaseDate.hashCode() : 0);
        result = 31 * result + discCount;
        result = 31 * result + typeId;
        return (int) result;
    }

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public int getUserId() {
        return userId;
    }

    public void setUserId(int userId) {
        this.userId = userId;
    }

    public Date getReleaseDate() {
        return releaseDate;
    }

    public void setReleaseDate(Date releaseDate) {
        this.releaseDate = releaseDate;
    }

    public int getStatusId() {
        return statusId;
    }

    public void setStatusId(int statusId) {
        this.statusId = statusId;
    }

    public int getDiscCount() {
        return discCount;
    }

    public void setDiscCount(int discCount) {
        this.discCount = discCount;
    }

    public long getTypeId() {
        return typeId;
    }

    public void setTypeId(long typeId) {
        this.typeId = typeId;
    }
}