package com.dominikdorn.lyrix.domain;

import javax.persistence.*;
import java.util.Date;

/**
 * Dominik Dorn
 * 0626165
 * dominik.dorn@tuwien.ac.at
 */
@IdClass(AlbumTitlePK.class)
@Entity
@Table(name = "lytalbumtitle", schema = "lyriks")
public class AlbumTitle {

    @Column(name = "nalbumnr")
    @Id
    private int albumId;

    @Column(name = "ntitlenr")
    @Id
    private int titleId;


    @Column(name = "ncd")
    @Basic
    private int cdNumber;


    @Column(name = "ntrack")
    @Basic
    private int trackNumber;

    /**
     * 1430     lytalbumtitle	hidden
     * 1420     lytalbumtitle	deleted
     * 1410 	lytalbumtitle	online
     * 1460 	lytalbumtitle	unapproved
     * 1450 	lytalbumtitle	lockedveto
     * 1440 	lytalbumtitle	lockeddubious
     */
    @Column(name = "nstatusnr")
    @Basic
    private int statusId;

    /**
     * 410  	lytalbumtitle	normal	Normaler Titel
     * 420      lytalbumtitle	data	Data Track
     */
    @Column(name = "ntypenr")
    @Basic
    private int typeId;


    @Column(name = "nusernr")
    @Basic
    private int userId;


    @Column(name = "dcreate")
    @Basic
    @Temporal(TemporalType.TIMESTAMP)
    private Date creationDate;


    @ManyToOne
    @JoinColumn(
            name = "ntitlenr",
            referencedColumnName = "ntitlenr",
            nullable = false, table = "lytalbumtitle"
            , insertable = false, updatable = false
    )
    private Title title;

    @ManyToOne
    @JoinColumn(
            name = "nalbumnr",
            referencedColumnName = "nalbumnr",
            nullable = false, table = "lytalbumtitle"
            , insertable = false, updatable = false
    )
    private Album album;


    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        AlbumTitle that = (AlbumTitle) o;

        if (albumId != that.albumId) return false;
        if (cdNumber != that.cdNumber) return false;
        if (statusId != that.statusId) return false;
        if (titleId != that.titleId) return false;
        if (trackNumber != that.trackNumber) return false;
        if (userId != that.userId) return false;
        if (creationDate != null ? !creationDate.equals(that.creationDate) : that.creationDate != null) return false;
        if (title != null ? !title.equals(that.title) : that.title != null) return false;

        return true;
    }

    @Override
    public int hashCode() {
        int result = albumId;
        result = 31 * result + titleId;
        result = 31 * result + cdNumber;
        result = 31 * result + trackNumber;
        result = 31 * result + statusId;
        result = 31 * result + userId;
        result = 31 * result + (creationDate != null ? creationDate.hashCode() : 0);
        result = 31 * result + (title != null ? title.hashCode() : 0);
        return result;
    }


    public int getAlbumId() {
        return albumId;
    }

    public void setAlbumId(int albumId) {
        this.albumId = albumId;
    }

    public int getTitleId() {
        return titleId;
    }

    public void setTitleId(int titleId) {
        this.titleId = titleId;
    }

    public int getCdNumber() {
        return cdNumber;
    }

    public void setCdNumber(int cdNumber) {
        this.cdNumber = cdNumber;
    }

    public int getTrackNumber() {
        return trackNumber;
    }

    public void setTrackNumber(int trackNumber) {
        this.trackNumber = trackNumber;
    }

    public int getStatusId() {
        return statusId;
    }

    public void setStatusId(int statusId) {
        this.statusId = statusId;
    }

    public int getTypeId() {
        return typeId;
    }

    public void setTypeId(int typeId) {
        this.typeId = typeId;
    }

    public int getUserId() {
        return userId;
    }

    public void setUserId(int userId) {
        this.userId = userId;
    }

    public Date getCreationDate() {
        return creationDate;
    }

    public void setCreationDate(Date creationDate) {
        this.creationDate = creationDate;
    }

    public Title getTitle() {
        return title;
    }

    public void setTitle(Title title) {
        this.title = title;
    }

    public Album getAlbum() {
        return album;
    }

    public void setAlbum(Album album) {
        this.album = album;
    }
}