package com.dominikdorn.lyrix.domain;

import javax.persistence.*;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Null;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.Date;

/**
 * Dominik Dorn
 * 0626165
 * dominik.dorn@tuwien.ac.at
 */
@Table(name = "lytartist", schema = "lyriks")
@Entity
@XmlRootElement
@NamedQueries(
        {
                @NamedQuery(
                        name = "Artist_getByFirstChar",
                        query = "SELECT a FROM Artist a WHERE lower(a.name) like :letter ORDER BY a.name")
        }
)
public class Artist {

    public Artist() {
    }

    public Artist(String name, Long userId) {
        this.name = name;
        this.userId = userId;
        this.statusId = 1660;
        this.typeId = 510;
        this.creationDate = new Date();
    }

    public Artist(long id, String name, Long userId) {
        this(name, userId);
        this.id = id;
    }


    @NotNull
    @Column(name = "nartistnr")
    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "artist_gen")
    @SequenceGenerator(name = "artist_gen",
            sequenceName = "lytartist_nartistnr_seq", allocationSize = 1)
    private long id;

    @Column(name = "sartist", length = 250, nullable = false)
    @Basic
    @NotNull
    private String name;

    @Column(name = "nartistnralias")
    @Basic
    private Integer aliasArtistId; // TODO this should be an artist too!


    /**
     * 1670     lytartist	autoadded
     * 1660 	lytartist	unapproved
     * 1650 	lytartist	lockedveto
     * 1640 	lytartist	lockeddubious
     * 1630 	lytartist	hidden
     * 1620 	lytartist	deleted
     * 1610 	lytartist	online
     */
    @Column(name = "nstatusnr")
    @Basic
    @NotNull
    private long statusId;

    /**
     * 510  	lytartist	artist	Normaler Artist
     * 520  	lytartist	movie	Film
     * 530     	lytartist	compilation	Compilation
     * 540  	lytartist	charts	Charts....
     * 550      lytartist	musical	Musical/Opera
     * 560  	lytartist	undefined	Undefiniert
     */
    @Column(name = "ntypenr")
    @Basic
    @NotNull
    private long typeId;


    @Column(name = "surl")
    @Basic
    private String url;


    @Column(name = "nlabelnr")
    @Basic
    private Long labelId;

    @Column(name = "nusernr")
    @Basic
    @NotNull
    private Long userId;

    @Column(name = "dnow")
    @Basic
    @NotNull
    @Temporal(TemporalType.TIMESTAMP)
    private Date creationDate;


    @Column(name = "ssoundex")
    @Basic
    @NotNull
    private String soundex;




    public long getStatusId() {
        return statusId;
    }

    public void setStatusId(long statusId) {
        this.statusId = statusId;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }


    public Long getLabelId() {
        return labelId;
    }

    public void setLabelId(Long labelId) {
        this.labelId = labelId;
    }

    public Long getUserId() {
        return userId;
    }


    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Date getCreationDate() {
        return creationDate;
    }

    public void setCreationDate(Date creationDate) {
        this.creationDate = creationDate;
    }


    public String getSoundex() {
        return soundex;
    }

    public void setSoundex(String soundex) {
        this.soundex = soundex;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Artist artist = (Artist) o;

        if (id != artist.id) return false;
        if (statusId != artist.statusId) return false;
        if (typeId != artist.typeId) return false;
        if (aliasArtistId != null ? !aliasArtistId.equals(artist.aliasArtistId) : artist.aliasArtistId != null)
            return false;
        if (!creationDate.equals(artist.creationDate)) return false;
        if (labelId != null ? !labelId.equals(artist.labelId) : artist.labelId != null) return false;
        if (!name.equals(artist.name)) return false;
        if (soundex != null ? !soundex.equals(artist.soundex) : artist.soundex != null) return false;
        if (!url.equals(artist.url)) return false;
        if (!userId.equals(artist.userId)) return false;

        return true;
    }

    @Override
    public int hashCode() {
        int result = (int) (id ^ (id >>> 32));
        result = 31 * result + name.hashCode();
        result = 31 * result + (aliasArtistId != null ? aliasArtistId.hashCode() : 0);
        result = 31 * result + (int) (statusId ^ (statusId >>> 32));
        result = 31 * result + (int) (typeId ^ (typeId >>> 32));
        result = 31 * result + url.hashCode();
        result = 31 * result + (labelId != null ? labelId.hashCode() : 0);
        result = 31 * result + userId.hashCode();
        result = 31 * result + creationDate.hashCode();
        result = 31 * result + (soundex != null ? soundex.hashCode() : 0);
        return result;
    }


    //    private Collection<LytartistElixic> lytartistElixicsByNartistnr;
//
//    @OneToMany(mappedBy = "lytartistByNartistnr")
//    public Collection<LytartistElixic> getLytartistElixicsByNartistnr() {
//        return lytartistElixicsByNartistnr;
//    }
//
//    public void setLytartistElixicsByNartistnr(Collection<LytartistElixic> lytartistElixicsByNartistnr) {
//        this.lytartistElixicsByNartistnr = lytartistElixicsByNartistnr;
//    }
//
//    private LytartistUrlname lytartistUrlnameByNartistnr;
//
//    @OneToOne(mappedBy = "lytartistByNartistnr")
//    public LytartistUrlname getLytartistUrlnameByNartistnr() {
//        return lytartistUrlnameByNartistnr;
//    }
//
//    public void setLytartistUrlnameByNartistnr(LytartistUrlname lytartistUrlnameByNartistnr) {
//        this.lytartistUrlnameByNartistnr = lytartistUrlnameByNartistnr;
//    }
//
//    private LytartistZoozle lytartistZoozleByNartistnr;
//
//    @OneToOne(mappedBy = "lytartistByNartistnr")
//    public LytartistZoozle getLytartistZoozleByNartistnr() {
//        return lytartistZoozleByNartistnr;
//    }
//
//    public void setLytartistZoozleByNartistnr(LytartistZoozle lytartistZoozleByNartistnr) {
//        this.lytartistZoozleByNartistnr = lytartistZoozleByNartistnr;
//    }
//
//    private Collection<FavoriteArtist> lytuserartistfavoritesByNartistnr;
//
//    @OneToMany(mappedBy = "lytartistByNartistnr")
//    public Collection<FavoriteArtist> getLytuserartistfavoritesByNartistnr() {
//        return lytuserartistfavoritesByNartistnr;
//    }
//
//    public void setLytuserartistfavoritesByNartistnr(Collection<FavoriteArtist> lytuserartistfavoritesByNartistnr) {
//        this.lytuserartistfavoritesByNartistnr = lytuserartistfavoritesByNartistnr;
//    }

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }


    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public int getAliasArtistId() {
        return aliasArtistId;
    }

    public void setAliasArtistId(Integer aliasArtistId) {
        this.aliasArtistId = aliasArtistId;
    }

    public long getTypeId() {
        return typeId;
    }

    public void setTypeId(long typeId) {
        this.typeId = typeId;
    }
}