package com.dominikdorn.lyrix.domain;

import javax.persistence.*;
import java.util.Date;

/**
 * Dominik Dorn
 * 0626165
 * dominik.dorn@tuwien.ac.at
 */
@Entity
@Table(name = "lytartisttitle", schema = "lyriks",
        uniqueConstraints = { @UniqueConstraint(columnNames = {"nartistnr", "ntitlenr"})} )
public class ArtistTitle {
    @Id
    @Column(name = "nartisttitlenr")
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "artist_title_gen")
    @SequenceGenerator(name = "artist_title_gen",
            sequenceName = "lytartisttitle_nartisttitlenr_seq",
            allocationSize = 1)
    private long id;

    @Column(name = "nartistnr")
    @Basic
    private long artistId;

    @Column(name = "ntitlenr")
    @Basic
    private long titleId;


    @Column(name = "dnow")
    @Basic
    @Temporal(TemporalType.TIMESTAMP)
    private Date creationDate;

    @Column(name = "nusernr")
    @Basic
    private long userId;

    /**
     * 1510 	lytartisttitle	online
     * 1520 	lytartisttitle	deleted
     * 1530 	lytartisttitle	hidden
     * 1540 	lytartisttitle	lockeddubious
     * 1550 	lytartisttitle	lockedveto
     * 1560 	lytartisttitle	unapproved
     */
    @Column(name = "nstatusnr")
    @Basic
    private int statusId;


    @ManyToOne
    @JoinColumn(name = "ntitlenr", referencedColumnName = "ntitlenr", nullable = false, table = "lytartisttitle", insertable = false, updatable = false)
    private Title title;

    @ManyToOne
    @JoinColumn(name = "nartistnr", referencedColumnName = "nartistnr", nullable = false, table = "lytartisttitle", insertable = false, updatable = false)
    private Artist artist;


    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public long getArtistId() {
        return artistId;
    }

    public void setArtistId(long artistId) {
        this.artistId = artistId;
    }

    public long getTitleId() {
        return titleId;
    }

    public void setTitleId(long titleId) {
        this.titleId = titleId;
    }

    public Date getCreationDate() {
        return creationDate;
    }

    public void setCreationDate(Date creationDate) {
        this.creationDate = creationDate;
    }

    public long getUserId() {
        return userId;
    }

    public void setUserId(long userId) {
        this.userId = userId;
    }

    public int getStatusId() {
        return statusId;
    }

    public void setStatusId(int statusId) {
        this.statusId = statusId;
    }

    public Title getTitle() {
        return title;
    }

    public void setTitle(Title title) {
        this.title = title;
    }

    public Artist getArtist() {
        return artist;
    }

    public void setArtist(Artist artist) {
        this.artist = artist;
    }


    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        ArtistTitle that = (ArtistTitle) o;

        if (artistId != that.artistId) return false;
        if (id != that.id) return false;
        if (statusId != that.statusId) return false;
        if (titleId != that.titleId) return false;
        if (userId != that.userId) return false;
        if (!creationDate.equals(that.creationDate)) return false;

        return true;
    }

    @Override
    public int hashCode() {
        int result = (int) (id ^ (id >>> 32));
        result = 31 * result + (int) (artistId ^ (artistId >>> 32));
        result = 31 * result + (int) (titleId ^ (titleId >>> 32));
        result = 31 * result + creationDate.hashCode();
        result = 31 * result + (int) (userId ^ (userId >>> 32));
        result = 31 * result + statusId;
        return result;
    }
}