package com.dominikdorn.lyrix.domain;

import javax.persistence.*;
import javax.xml.bind.annotation.XmlRootElement;
import java.sql.Timestamp;
import java.util.Date;
import java.util.UUID;

/**
 * Dominik Dorn
 * 0626165
 * dominik.dorn@tuwien.ac.at
 */
@Table(name = "lyttext", schema = "lyriks")
@Entity
@XmlRootElement
public class Text {
    @Id
    @Column(name = "ntextnr")
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "text_gen")
    @SequenceGenerator(name = "text_gen",
            sequenceName = "lyttext_ntextnr_seq", allocationSize = 1)
    private long id;

    @Column(name = "dnow", nullable = false)
    @Basic
    @Temporal(TemporalType.TIMESTAMP)
    private Date creationDate;

    @Column(name = "nusernr", nullable = false)
    @Basic
    private long userId;

    // here titleId
    @ManyToOne
    @JoinColumn(name = "ntitlenr", referencedColumnName = "ntitlenr", insertable = false, updatable = false)
    private Title title;


    @Column(name = "ntitlenr")
    @Basic
    private long titleId;

    /**
     * 110  	lyttext	lyric	Lyrics
     * 120  	lyttext	translation	&Uuml;bersetzung
     * 130  	lyttext	accord	Akkord
     * 140  	lyttext	tab	Tabulator
     */
    @Column(name = "ntypenr", nullable = false)
    @Basic
    private long typeId;


    /**
     * 1110     lyttext	online	Online
     * 1120 	lyttext	deleted	Geloescht
     * 1130 	lyttext	hidden	Versteckt(/geloescht)
     * 1140 	lyttext	lockeddubious	Gesperrt wg. Inhalt
     * 1150 	lyttext	lockedveto	Einspruch Verlag
     * 1160   	lyttext	unapproved
     */
    @Column(name = "nstatusnr",nullable = false)
    @Basic
    private long statusId;


    @Column(name = "slanguageid", length = 5, nullable = false)
    @Basic
    private String languageId;


    @Column(name = "stexthash",length = 32, nullable = false)
    @Basic
    private String hash;

    @Column(name = "stext", nullable = false)
    @Basic
    private String text;

    @Column(name = "nviewed", nullable = false)
    @Basic
    private int viewCount;

    @Column(name = "nrating", nullable = false)
    @Basic
    private int rating;


    @Column(name = "nrevisionnr", nullable = false)
    @Basic
    private int version;


    @Column(name = "nusernrcorrector", nullable = true)
    @Basic
    private Long correctorUserId;

    @Column(name = "islastversion")
    @Basic
    private boolean lastVersion;

    public Text() {
    }

    public Text(long titleId, String text, long userId, long typeId, String languageId) {
        this.titleId = titleId;
        this.text = text;
        this.userId = userId;
        this.statusId = 1160;
        this.typeId = typeId;
        this.hash = UUID.randomUUID().toString().replaceAll("-","").toLowerCase();
        this.languageId = languageId;
        this.creationDate = new Timestamp(new Date().getTime());
    }


    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Text text = (Text) o;

        if (lastVersion != text.lastVersion) return false;
        if (rating != text.rating) return false;
        if (version != text.version) return false;
        if (id != text.id) return false;
        if (typeId != text.typeId) return false;
        if (userId != text.userId) return false;
        if (correctorUserId != text.correctorUserId) return false;
        if (viewCount != text.viewCount) return false;
        if (creationDate != null ? !creationDate.equals(text.creationDate) : text.creationDate != null) return false;
        if (this.text != null ? !this.text.equals(text.text) : text.text != null) return false;
        if (hash != null ? !hash.equals(text.hash) : text.hash != null) return false;

        return true;
    }

    @Override
    public int hashCode() {
        long result = id;
        result = 31 * result + (creationDate != null ? creationDate.hashCode() : 0);
        result = 31 * result + userId;
        result = 31 * result + typeId;
        result = 31 * result + (hash != null ? hash.hashCode() : 0);
        result = 31 * result + (text != null ? text.hashCode() : 0);
        result = 31 * result + viewCount;
        result = 31 * result + rating;
        result = 31 * result + version;
        result = 31 * result + (lastVersion ? 1 : 0);
        return (int) result;
    }

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public Date getCreationDate() {
        return creationDate;
    }

    public void setCreationDate(Date creationDate) {
        this.creationDate = creationDate;
    }

    public long getUserId() {
        return userId;
    }

    public void setUserId(long userId) {
        this.userId = userId;
    }

    public Title getTitle() {
        return title;
    }

    public void setTitle(Title title) {
        this.title = title;
    }

    public long getTypeId() {
        return typeId;
    }

    public void setTypeId(long typeId) {
        this.typeId = typeId;
    }

    public String getHash() {
        return hash;
    }

    public void setHash(String hash) {
        this.hash = hash;
    }

    public String getText() {
        return text;
    }

    public void setText(String text) {
        this.text = text;
    }

    public int getViewCount() {
        return viewCount;
    }

    public void setViewCount(int viewCount) {
        this.viewCount = viewCount;
    }

    public int getRating() {
        return rating;
    }

    public void setRating(int rating) {
        this.rating = rating;
    }

    public int getVersion() {
        return version;
    }

    public void setVersion(int version) {
        this.version = version;
    }

    public Long getCorrectorUserId() {
        return correctorUserId;
    }

    public void setCorrectorUserId(Long correctorUserId) {
        this.correctorUserId = correctorUserId;
    }

    public boolean isLastVersion() {
        return lastVersion;
    }

    public void setLastVersion(boolean lastVersion) {
        this.lastVersion = lastVersion;
    }

    public long getTitleId() {
        return titleId;
    }

    public void setTitleId(long titleId) {
        this.titleId = titleId;
    }

    public long getStatusId() {
        return statusId;
    }

    public void setStatusId(long statusId) {
        this.statusId = statusId;
    }

    public String getLanguageId() {
        return languageId;
    }

    public void setLanguageId(String languageId) {
        this.languageId = languageId;
    }
}