package com.dominikdorn.lyrix.domain;

import javax.persistence.*;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import java.util.Collection;
import java.util.Date;

/**
 * Dominik Dorn
 * 0626165
 * dominik.dorn@tuwien.ac.at
 */
@Table(name = "lyttitle", schema = "lyriks")
@Entity
@XmlRootElement
public class Title {
    @Column(name = "ntitlenr")
    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "title_gen")
    @SequenceGenerator(name = "title_gen",
            sequenceName = "lyttitle_ntitlenr_seq", allocationSize = 1)
    private long id;

    @Column(name = "stitle")
    @Basic
    private String name;

    @Column(name = "nusernr")
    @Basic
    private long userId;

    @Column(name = "dnow")
    @Basic
    @Temporal(TemporalType.TIMESTAMP)
    private Date creationDate;


    /**
     * 1210 	lyttitle	online
     * 1220 	lyttitle	deleted
     * 1230 	lyttitle	hidden
     * 1240 	lyttitle	lockeddubious
     * 1250	    lyttitle	lockedveto
     * 1251     lyttitle	lockedvetonewtitle	Einspruch & neuer Titel
     * 1260 	lyttitle	unapproved
     */
    @Column(name = "nstatusnr")
    @Basic
    private long statusId;

    /**
     * 210  	lyttitle	standard	Normaler Titel
     * 220  	lyttitle	instrumental	Instrumental-Track - kein Text
     * 230  	lyttitle	data	Daten-Track
     * 240      lyttitle	video	Video
     */
    @Column(name = "ntypenr")
    @Basic
    private long typeId;

    @Column(name = "nseconds")
    @Basic
    private Long seconds;

    @Column(name = "ntitlenralias")
    @Basic
    private Long aliasTitleId;

    @Column(name = "ssoundex")
    @Basic
    private String soundex;

    @OneToMany(mappedBy = "title", fetch = FetchType.LAZY)
    @XmlTransient
    private Collection<Text> texts;


    @OneToMany(mappedBy = "title", fetch = FetchType.LAZY)
    @XmlTransient
    private Collection<Video> videos;


    public Title() {
    }

    public Title(String name, int userId) {
        this.name = name;
        this.userId = userId;
        this.statusId = 1260;
        this.typeId = 210;
    }

    public Title(long id, String name, int userId) {
        this(name,userId);
        this.id = id;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Title title = (Title) o;

        if (seconds != title.seconds) return false;
        if (id != title.id) return false;
        if (aliasTitleId != title.aliasTitleId) return false;
        if (userId != title.userId) return false;
        if (creationDate != null ? !creationDate.equals(title.creationDate) : title.creationDate != null) return false;
        if (soundex != null ? !soundex.equals(title.soundex) : title.soundex != null) return false;
        if (name != null ? !name.equals(title.name) : title.name != null) return false;

        return true;
    }

    @Override
    public int hashCode() {
        long result = id;
        result = 31 * result + (name != null ? name.hashCode() : 0);
        result = 31 * result + userId;
        result = 31 * result + (creationDate != null ? creationDate.hashCode() : 0);
        result = 31 * result + seconds;
        result = 31 * result + (soundex != null ? soundex.hashCode() : 0);
        return (int) result;
    }

//    private Collection<AlbumTitle> albumTitles;
//
//    @OneToMany(mappedBy = "lyttitleByNtitlenr")
//    public Collection<AlbumTitle> getAlbumTitles() {
//        return albumTitles;
//    }
//
//    public void setAlbumTitles(Collection<AlbumTitle> albumTitles) {
//        this.albumTitles = albumTitles;
//    }

//    private Collection<ArtistTitle> artistTitles;
//
//    @OneToMany(mappedBy = "lyttitleByNtitlenr")
//    public Collection<ArtistTitle> getArtistTitles() {
//        return artistTitles;
//    }
//
//    public void setArtistTitles(Collection<ArtistTitle> artistTitles) {
//        this.artistTitles = artistTitles;
//    }


    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public long getUserId() {
        return userId;
    }

    public void setUserId(long userId) {
        this.userId = userId;
    }

    public Date getCreationDate() {
        return creationDate;
    }

    public void setCreationDate(Date creationDate) {
        this.creationDate = creationDate;
    }

    public long getStatusId() {
        return statusId;
    }

    public void setStatusId(long statusId) {
        this.statusId = statusId;
    }

    public Long getSeconds() {
        return seconds;
    }

    public void setSeconds(Long seconds) {
        this.seconds = seconds;
    }

    public Long getAliasTitleId() {
        return aliasTitleId;
    }

    public void setAliasTitleId(Long aliasTitleId) {
        this.aliasTitleId = aliasTitleId;
    }

    public String getSoundex() {
        return soundex;
    }

    public void setSoundex(String soundex) {
        this.soundex = soundex;
    }

    @XmlTransient
    public Collection<Text> getTexts() {
        return texts;
    }

    public void setTexts(Collection<Text> texts) {
        this.texts = texts;
    }

    @XmlTransient
    public Collection<Video> getVideos() {
        return videos;
    }

    public void setVideos(Collection<Video> videos) {
        this.videos = videos;
    }

    public long getTypeId() {
        return typeId;
    }

    public void setTypeId(long typeId) {
        this.typeId = typeId;
    }
}