package com.dominikdorn.lyrix.rs.resources;

import com.dominikdorn.lyrix.domain.Artist;
import com.dominikdorn.lyrix.domain.Title;
import com.dominikdorn.lyrix.rs.httpmethods.GETBYLETTER;
import com.dominikdorn.lyrix.service.lyrics.ArtistService;
import com.dominikdorn.lyrix.service.dc.UserService;

import javax.annotation.ManagedBean;
import javax.annotation.PostConstruct;
import javax.inject.Inject;
import javax.persistence.*;
import javax.transaction.*;
import javax.ws.rs.*;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.SecurityContext;
import java.util.ArrayList;
import java.util.List;

/**
 * Dominik Dorn
 * 0626165
 * dominik.dorn@tuwien.ac.at
 */
//@Path("/api/lyrics/artists")
@Path("artists")
@ManagedBean
public class ArtistResource {

    @Inject
    UserService userService;

    @Inject
    ArtistService artistService;

    @Inject
    UserTransaction tx;

    @PostConstruct
    public void postConstruct()
    {
        System.out.println("called post construct");
    }

    @PersistenceContext
    EntityManager em;

//    @GET
//    @Path("/")
//    @Produces("application/json")
    public List<Artist> getAll()
    {
        return new ArrayList<Artist>();
    }

    @GET
    @Path("/{artistId: [0-9]+}")
    @Produces("application/json")
    public Artist getArtistById(@PathParam("artistId") long id)
    {
        Artist a = artistService.findById(id);
        if(a == null)
            a = new Artist();
        return a;
    }



    @POST
    @Path("/")
    @Produces("application/json")
    public Artist persistArtist(@FormParam("name") String artistName, @Context SecurityContext securityContext)
    {
        if(null == securityContext.getUserPrincipal())
            return null;

        String username = securityContext.getUserPrincipal().getName();
        long userId = userService.getUserId(username);
        Artist artist = null;
        try {
            tx.begin();
            artist = artistService.createArtist(artistName, userId);
            tx.commit();
        } catch (NotSupportedException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        } catch (SystemException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        } catch (javax.transaction.RollbackException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        } catch (HeuristicMixedException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        } catch (HeuristicRollbackException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
        return artist;
    }



    @GET
    @Path("/{artistId: [0-9]+}/titles")
    @Produces("application/json")
    public List<Title> getTitlesByArtist(@PathParam("artistId") long artistId)
    {
        List<Title> result = artistService.getTitles(artistId);

        return result;       
    }

    @GETBYLETTER
    @Path("/{letter: [a-z]{1}}")
    @Produces("application/json")
    public List<Artist> getByLetter(@PathParam("letter") String letter){
        if(letter.length() != 1)
            return null;

        letter = letter.toLowerCase();
        List<Artist> result = artistService.getArtistsByLetter(letter);

        for(Artist a : result)
        {
            a.setCreationDate(null);
            a.setLabelId(null);
            a.setSoundex(null);
            a.setUrl(null);
            a.setUserId(null);
            a.setAliasArtistId(null);
        }
        return result;
    }

    @GET
    @Path("/")
    @Produces("text/plain")
    public String defaultValue(){
        return "/artists/";
    }

    
}
