package com.dominikdorn.lyrix.rs.resources;

import com.dominikdorn.lyrix.domain.Text;
import com.dominikdorn.lyrix.service.dc.UserService;
import com.dominikdorn.lyrix.service.lyrics.LyricsService;
import com.dominikdorn.lyrix.service.lyrics.TitleService;

import javax.annotation.ManagedBean;
import javax.inject.Inject;
import javax.transaction.*;
import javax.ws.rs.*;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.SecurityContext;

/**
 * Dominik Dorn
 * 0626165
 * dominik.dorn@tuwien.ac.at
 */
@Path("/api/lyrics/texts")
@ManagedBean
public class TextResource {

    @Inject
    LyricsService lyricsService;

    @Inject
    UserService userService;

    @Inject
    UserTransaction tx;


    @POST
    @Produces(MediaType.APPLICATION_JSON)
    public Text createText(
            @FormParam("titleId") long titleId,
            @FormParam("typeId") long typeId,
            @FormParam("languageId") String languageId,
            @FormParam("text") String text,
            @Context SecurityContext securityContext)
    {
        if(null == securityContext.getUserPrincipal())
            return null;

        String username = securityContext.getUserPrincipal().getName();

        long userId = userService.getUserId(username);

        if(userId < 1)
            return null;

        try {
            Text t = null;
            tx.begin();
            t = lyricsService.createText(titleId, text, typeId, languageId, userId);
            tx.commit();
            return t;
        } catch (NotSupportedException e) {
            throw new RuntimeException(e);
        } catch (SystemException e) {
            throw new RuntimeException(e);
        } catch (RollbackException e) {
            throw new RuntimeException(e);
        } catch (HeuristicMixedException e) {
            throw new RuntimeException(e);
        } catch (HeuristicRollbackException e) {
            throw new RuntimeException(e);
        }
    }

    @GET
    @Path("/")
    @Produces("text/plain")
    public String defaultValue(){
        return "/texts/";
    }

}
