package com.dominikdorn.lyrix.service.lyrics;

import com.dominikdorn.lyrix.dao.ArtistDao;
import com.dominikdorn.lyrix.domain.Artist;
import com.dominikdorn.lyrix.domain.Title;
import org.apache.commons.codec.language.Soundex;

import javax.annotation.ManagedBean;
import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;
import java.util.ArrayList;
import java.util.List;

/**
 * Dominik Dorn
 * 0626165
 * dominik.dorn@tuwien.ac.at
 */
@ManagedBean
public class ArtistServiceImpl implements ArtistService {

    @PersistenceContext
    EntityManager em;


    @Inject
    ArtistDao artistDao;

    @Override
    public List<Artist> getArtistsByLetter(String letter) {
        letter = letter.toLowerCase();
//        return new ArrayList<Artist>();
        List<Artist> result =
                em.createQuery("SELECT a FROM Artist a WHERE lower(a.name) like :letter ORDER BY a.name", Artist.class)
                        .setParameter("letter", letter.charAt(0) + "%")
                        .setHint("eclipselink.jdbc.bind-parameters", true)
                        .getResultList();
        return result;        
    }

    @Override
    public Artist createArtist(String name, long userId) {

        /**
         *     $sArtist = stripslashes( trim( $sArtist ) );
    $sArtist = str_replace( '"',"'", $sArtist );
         */

        name = name.trim().replace('"','\'');

        String soundex = null;

        
//        if(name != null)
//            soundex = Soundex.US_ENGLISH.encode(name);

        if(null == soundex)
            soundex = "0000";

        Artist a = new Artist(name, userId);
        a.setSoundex(soundex);
        a.setUrl("");




        // TODO

        a = artistDao.create(a);

        em.createNativeQuery("update lyriks.lytartist set surlname = initcap(btrim(regexp_replace( regexp_replace(lower(translate(sartist,'èéääööäöö´ÖÄäÜ’’äéï´Â´ââüłę','eeaaooaoo''OAaU''''aei''A''aaule')), '[^a-zA-Z0-9]','-','g'), E'-\\+','-','g'),'-')) where nartistnr = ?").
                setParameter(1, a.getId()).executeUpdate();
        
        a = artistDao.find(a.getId());

        return a;

    }

    @Override
    public List<Title> getTitles(long artistId) {

        /**
         * 		$sSQLGetntitlenr = "SELECT
			b.ntitlenr,
			b.stitle
			FROM
			lytartisttitle a JOIN
			lyttitle b ON ( b.ntitlenr = a.ntitlenr ) JOIN
			lytartist c ON ( c.nartistnr = a.nartistnr )
			WHERE
			a.nartistnr = '$nartistnr'
			ORDER BY
			lower(b.stitle)
		";
         */

        Query q = em.createQuery("SELECT at.title FROM ArtistTitle at WHERE at.artistId = :artistId ORDER BY at.title.name ", Title.class);
        q.setParameter("artistId", artistId);
        List result = q.getResultList();

        if(result == null)
        {
            System.out.println("result is null!!!!!!");
            result = new ArrayList();
        }

        return result;
    }

    @Override
    public List<Artist> searchByName(String name) {
        // TODO Implement and remove /ajax/text/artist/search
        /**
         $sSQLGetArtists =
         "SELECT nartistnr, sartist,
         nartistnralias FROM lytartist WHERE
         sartist ilike '". $sartist ."%' AND
         nstatusnr IN (1610,1640,1650,1660,1670 ) LIMIT 40;" ;

         */

        return null;  //To change body of implemented methods use File | Settings | File Templates.
    }

    @Override
    public Artist findById(long id) {
        Artist a = artistDao.find(id);
        if(a == null)
            a = new Artist();
        return a;
    }
}
